__title__ = 'evernote2'
__description__ = 'another Evernote SDK for Python'
__url__ = 'https://github.com/JackonYang/evernote2'
__version__ = '1.0.0'
# __build__ = 0x022500
__author__ = 'Jackon Yang'
__author_email__ = 'i@jackon.me'
__license__ = 'BSD'
__copyright__ = 'Copyright 2020 Jackon Yang'
